// Load data
d3.text(
  'https://gist.githubusercontent.com/Mahesh-Polisetty/14316699380f4bc1beb720eb5ccd7fa9/raw/13f0454025771f8ed9d8deb145a5c6541b893fce/gistfile1.txt',
).then(function (text) {
  // Split the text into lines
  const lines = text.trim().split('\n');

  // Initialize an empty array to store the data
  const data = [];

  // Extract only the required states
  const statesToDisplay = [
    'California',
    'New York',
    'Texas',
    'Florida',
    'Illinois',
  ];

  for (let i = 0; i < lines.length; i++) {
    const lineData = lines[i].split(',');
    const state = lineData[0];
    if (statesToDisplay.includes(state)) {
      const stateData = {
        State: state,
        Values: lineData.slice(1).map(parseFloat),
      };
      data.push(stateData);
    }
  }

  // Setup SVG
  const margin = {
    top: 20,
    right: 20,
    bottom: 30,
    left: 50,
  };
  const width = 800 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  const svg = d3
    .select('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      'translate(' + margin.left + ',' + margin.top + ')',
    );

  // Set up scales
  const xScale = d3
    .scaleLinear()
    .domain([2020, 2023])
    .range([0, width]);

  const yScale = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d3.max(d.Values))])
    .range([height, 0]);

  // Draw area
  const area = d3
    .area()
    .x((d, i) => xScale(2020 + i))
    .y0(height)
    .y1((d) => yScale(d))
    .curve(d3.curveLinear);

  const color = d3.scaleOrdinal(d3.schemeCategory10);

  svg
    .selectAll('.area')
    .data(data)
    .enter()
    .append('path')
    .attr('class', 'area')
    .attr('d', (d) => area(d.Values))
    .style('fill', (d, i) => color(i))
    .style('opacity', 0.7);

  // Draw axes
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(
      d3
        .axisBottom(xScale)
        .ticks(4)
        .tickFormat(d3.format('d')),
    )
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.bottom - 10)
    .attr('fill', '#000')
    .attr('text-anchor', 'middle')
    .text('Year');

  svg
    .append('g')
    .call(d3.axisLeft(yScale).ticks(10))
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 10)
    .attr('x', -height / 2)
    .attr('dy', '0.71em')
    .attr('fill', '#000')
    .attr('text-anchor', 'middle')
    .text('Revenue (USD)');

  // Draw legend
  const legend = svg
    .append('g')
    .attr('class', 'legend')
    .attr(
      'transform',
      'translate(' + (width - 120) + ',' + 20 + ')',
    );

  data.forEach((d, i) => {
    legend
      .append('text')
      .attr('x', 0)
      .attr('y', i * 20)
      .attr('fill', color(i))
      .text(d.State);
  });

  // Chart title
  svg
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.top / 2)
    .attr('text-anchor', 'middle')
    .style('font-size', '16px')
    .text('Revenue of Selected States from 2020 to 2023');
});
